@@ -37,7 +37,9 @@ def findChanges(old_state,new_state):
             elif old_state[key]!=new_state.get(key,None):
                 if type(old_state[key]) in [type({}),type([])]:
                     try:
-                        res+= "<li>"+findChanges(old_state.get(key,{}),new_state.get(key,{}))+"</li>"
+                        c = findChanges(old_state.get(key, {}), new_state.get(key, {}))
+                        if c!="<ul></ul>":
+                            res+= "<li>"+c+"</li>"
                     except:
                         pass
                 else:
@@ -75,10 +77,11 @@ def fetchChanges(id,table):
                     change.new_state[key]=datetime.datetime.strptime(change.new_state[key]["value"],"%Y-%m-%d").date().strftime("%Y-%m-%d")
             if change.old_state.get(key, None) != change.new_state.get(key, None):
                 if type(change.old_state.get(key, None)) in [type({}), type([])]:
-                    text = "%s: <br/>" % key
                     keyChanges = findChanges(change.old_state[key], change.new_state[key])
-                    text += keyChanges
-                    row["changes"].append(mark_safe(text))
+                    if keyChanges!="<ul></ul>":
+                        text = "%s: <br/>" % key
+                        text += keyChanges
+                        row["changes"].append(mark_safe(text))
                 else:
                     row["changes"].append(
                         "%s: %s ----> %s" % (key, change.old_state.get(key, None), change.new_state[key]))
